@@ -12,10 +12,10 @@ import { validEmailRegex } from 'app/features/dashboard/components/ShareModal/Sh
 import { useRequestAccessMutation } from './api/emailSharingApi';
 import { getRequestAccessText } from './utils';
 
-const formStyles = css`
-  justify-content: center;
-  width: 100%;
-`;
+const formStyles = css({
+  justifyContent: 'center',
+  width: '100%',
+});
 
 interface FormData {
   email: string;
@@ -77,9 +77,9 @@ const RequestViewAccessPage = () => {
 };
 
 const getStyles = (theme: GrafanaTheme2) => ({
-  loadingSpinner: css`
-    margin-left: ${theme.spacing(1)};
-  `,
+  loadingSpinner: css({
+    marginLeft: theme.spacing(1),
+  }),
 });
 
 export default RequestViewAccessPage;
